@@ -25,19 +25,10 @@
 #include <string>
 #include <vector>
 #include <hx711/common.h>
-
-#ifdef USE_PYBIND_SUBMODULE
-#include "../extern/pybind11/include/pybind11/chrono.h"
-#include "../extern/pybind11/include/pybind11/operators.h"
-#include "../extern/pybind11/include/pybind11/pybind11.h"
-#include "../extern/pybind11/include/pybind11/stl.h"
-#else
 #include <pybind11/chrono.h>
 #include <pybind11/operators.h>
 #include <pybind11/pybind11.h>
 #include <pybind11/stl.h>
-#endif
-
 
 using namespace HX711;
 
